@@ -1,4 +1,4 @@
-#!/usr/bin/perl -nw
+#!/usr/bin/perl
 # Copyright (C) 2009-2011  Antonio Bonafonte
 #            Universitat Politècnica de Catalunya, Barcelona, Spain
 #
@@ -16,12 +16,23 @@
 #  License along with this library; if not, write to the Free Software
 #  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+use strict;
+use warnings;
+
+my $dialect = "$ARGV[0]";
+my $wrd;
+my $pos;
+my $trn;
+
+while (<STDIN>) {
 chomp;
 
 if (3 != (($wrd, $pos, $trn) = split /\t/)) {
     print STDERR "Format error line: $_\n";
 }
 
+if ( "$dialect" eq "central" ) {
+
 $trn =~ tr/BDGNv/bdgnf/;
 $trn =~ s/ts/t s/g;
 $trn =~ s/tS/t S/g;
@@ -30,4 +41,17 @@ $trn =~ s/dZ/d Z/g;
 $trn =~ s/uw/w/g;
 $trn =~ s/y/j/g;
 
+} elsif ("$dialect" eq "valencia" ) {
+
+$trn =~ tr/BDG/bdg/;
+$trn =~ s/ts/t s/g;
+$trn =~ s/dz/d z/g;
+$trn =~ s/uw/w/g;
+$trn =~ s/y/j/g;
+
+
+}
+
 print "$wrd\t$pos\t$trn\n";
+
+}
